]> git.tdb.fi Git - ext/subsurface.git/blobdiff - dive.h
Do better cylinder information management
[ext/subsurface.git] / dive.h
diff --git a/dive.h b/dive.h
index a8e3c319afd58cbc9011d910f17a409997d9f707..c6c545dcc11e133a748113f8529fce9a5128aeb6 100644 (file)
--- a/dive.h
+++ b/dive.h
@@ -1,6 +1,9 @@
 #ifndef DIVE_H
 #define DIVE_H
 
+#include <stdlib.h>
+#include <time.h>
+
 /*
  * Some silly typedefs to make our units very explicit.
  *
@@ -11,7 +14,7 @@
  *
  * We also strive to make '0' a meaningless number saying "not
  * initialized", since many values are things that may not have
* been reported (eg tank pressure or temperature from dive
  * computers that don't support them). But sometimes -1 is an even
  * more explicit way of saying "not there".
  *
@@ -19,7 +22,7 @@
  * temperatures. Doing temperatures in celsius or fahrenheit would
  * make for loss of precision when converting from one to the other,
  * and using millikelvin is SI-like but also means that a temperature
* of '0' is clearly just a missing temperature or tank pressure.
  *
  * Also strive to use units that can not possibly be mistaken for a
  * valid value in a "normal" system without conversion. If the max
@@ -66,14 +69,18 @@ typedef struct {
 
 typedef struct {
        fraction_t o2;
-       fraction_t n2;
-       fraction_t he2;
+       fraction_t he;
 } gasmix_t;
 
 typedef struct {
        volume_t size;
-       pressure_t pressure;
-} tank_type_t;
+       pressure_t workingpressure;
+} cylinder_type_t;
+
+typedef struct {
+       cylinder_type_t type;
+       gasmix_t gasmix;
+} cylinder_t;
 
 static inline int to_feet(depth_t depth)
 {
@@ -96,18 +103,23 @@ struct sample {
        duration_t time;
        depth_t depth;
        temperature_t temperature;
-       pressure_t tankpressure;
-       int tankindex;
+       pressure_t cylinderpressure;
+       int cylinderindex;
 };
 
+#define MAX_CYLINDERS (4)
+
 struct dive {
        const char *name;
        time_t when;
+       char *location;
+       char *notes;
        depth_t maxdepth, meandepth;
        duration_t duration, surfacetime;
        depth_t visibility;
        temperature_t airtemp, watertemp;
        pressure_t beginning_pressure, end_pressure;
+       cylinder_t cylinder[MAX_CYLINDERS];
        int samples;
        struct sample sample[];
 };
@@ -121,7 +133,25 @@ struct dive_table {
 
 extern struct dive_table dive_table;
 
+static inline struct dive *get_dive(unsigned int nr)
+{
+       if (nr >= dive_table.nr)
+               return NULL;
+       return dive_table.dives[nr];
+}
+
 extern void parse_xml_init(void);
 extern void parse_xml_file(const char *filename);
 
+extern void flush_dive_info_changes(void);
+extern void save_dives(const char *filename);
+
+static inline unsigned int dive_size(int samples)
+{
+       return sizeof(struct dive) + samples*sizeof(struct sample);
+}
+
+extern struct dive *fixup_dive(struct dive *dive);
+extern struct dive *try_to_merge(struct dive *a, struct dive *b);
+
 #endif /* DIVE_H */
@@ -11,7 +14,7 @@
  * We also strive to make '0' a meaningless number saying "not
  * initialized", since many values are things that may not have
- * been reported (eg tank pressure or temperature from dive
+ * been reported (eg cylinder pressure or temperature from dive
  * computers that don't support them). But sometimes -1 is an even
  * more explicit way of saying "not there".
@@ -19,7 +22,7 @@
  * make for loss of precision when converting from one to the other,
  * and using millikelvin is SI-like but also means that a temperature
- * of '0' is clearly just a missing temperature or tank pressure.
+ * of '0' is clearly just a missing temperature or cylinder pressure.
  *
  * Also strive to use units that can not possibly be mistaken for a